@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package GitHub::MergeVelocity;
-$GitHub::MergeVelocity::VERSION = '0.000001';
+$GitHub::MergeVelocity::VERSION = '0.000002';
 use CHI;
 use CLDR::Number::Format::Percent;
 use GitHub::MergeVelocity::Repository;
@@ -47,12 +47,6 @@ has github_user => (
     documentation => 'The username of your GitHub account',
 );
 
-has url => (
-    is       => 'ro',
-    isa      => ArrayRef,
-    required => 1,
-);
-
 has _report => (
     is       => 'ro',
     isa      => HashRef,
@@ -80,9 +74,6 @@ has _mech => (
 has url => (
     is     => 'ro',
     isa    => ArrayRef,
-    traits => ['Array'],
-
-    #    handles => { '_all_repositories' => 'elements' },
     required => 1,
 );
 
@@ -210,7 +201,7 @@ GitHub::MergeVelocity - Determine how quickly your pull request might get merged
 
 =head1 VERSION
 
-version 0.000001
+version 0.000002
 
 =head1 SYNOPSIS
 
@@ -242,7 +233,7 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Olaf Alders.
+This software is copyright (c) 2015 by Olaf Alders.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
